function [confidence,labels] = manClass(data,type,event)
% 
% INPUT:
% data is [n,M] array of M observations.
% type is car indicating type of blood pressure monitor used.
% event is char indicating type of cardiac event to classify.
%
% Dependency: load a struc called parameters with:
% parameters.kernelType
% parameters.trainData [n,N]
% parameters.kernelParameter
% parameters.a
% parameters.b

switch type
    case 'abp'
    switch event
        case 'Asystole'
            load('Aa_model.mat');
        case 'Bradycardia'
            load('Ba_model.mat');
        case 'Tachycardia'
            load('Ta_model.mat');
        case 'Ventricular_Tachycardia'
            load('VTa_model.mat');
        case 'Ventricular_Flutter_Fib'
            load('VFFa_model.mat');
    end
    case 'ppg'
        switch event
            case 'Asystole'
                load('Ap_model.mat');
            case 'Bradycardia'
                load('Bp_model.mat');
            case 'Tachycardia'
                load('Tp_model.mat');
            case 'Ventricular_Tachycardia'
                load('VTp_model.mat');
            case 'Ventricular_Flutter_Fib'
                load('VFFp_model.mat');
        end
end
% Should have loaded a struc called 'parameters'

switch parameters.kernelType
    case 'rbf'
        Kernel = exp(-(repmat(sum(parameters.trainData.*parameters.trainData,1),size(data,2),1)...
            + repmat(sum(data.*data,1)',1,size(parameters.trainData,2)) ...
            - 2*(parameters.trainData'*data)')...
            /(2*parameters.kernelParameter^2)); 
end

confidence = parameters.a*Kernel'-parameters.b;
labels = sign(confidence);


end